==> haskell-missingh-1.4.1.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.1.0
id: MissingH-1.4.1.0-2k2reSH2SdKKj1RsoyEJMU
key: MissingH-1.4.1.0-2k2reSH2SdKKj1RsoyEJMU
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
abi: 5b5f7a802652bc187c35eaf77c269245
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/MissingH-1.4.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/MissingH-1.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/MissingH-1.4.1.0
hs-libraries: HSMissingH-1.4.1.0-2k2reSH2SdKKj1RsoyEJMU
depends:
    network-2.7.0.2-DHEaxB3Qzor483iLxewsye parsec-3.1.13.0
    base-4.11.1.0 mtl-2.2.2 HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    regex-compat-0.95.1-GpayP5pCY7oFkOLgNVrkag filepath-1.4.2
    hslogger-1.2.12-8KrBGGjm3kk1o6iDSYYpSJ directory-1.3.1.5
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV process-1.6.3.0
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu containers-0.5.11.0
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh array-0.5.2.0
    time-1.8.0.2 unix-2.7.2.2
abi-depends: network-2.7.0.2-DHEaxB3Qzor483iLxewsye=6aeecf5609d81737c1dbc231763db621
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             regex-compat-0.95.1-GpayP5pCY7oFkOLgNVrkag=af6f71e3e9a26b52511ae7ff4847855c
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hslogger-1.2.12-8KrBGGjm3kk1o6iDSYYpSJ=b80042867093051be09edcab7eb4aa97
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.4.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.1.0
id: MissingH-1.4.1.0-46jRKG8uuG63p0c9C5W8iY
key: MissingH-1.4.1.0-46jRKG8uuG63p0c9C5W8iY
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
abi: 19b98bcc98ccea0300f3cacf1cc3fe5b
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/MissingH-1.4.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/MissingH-1.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/MissingH-1.4.1.0
hs-libraries: HSMissingH-1.4.1.0-46jRKG8uuG63p0c9C5W8iY
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj array-0.5.3.0 base-4.12.0.0
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    hslogger-1.2.12-CxYawsQ3FGm5vZk00Myalx mtl-2.2.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    process-1.6.3.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-compat-0.95.1-KWHpBxMrkPb1MX7UzruPB9 time-1.8.0.2
    unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
